==> haskell-simple-sendfile-0.2.28-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.28
id: simple-sendfile-0.2.28-2jBEu40P91F3SXyDycEM4A
key: simple-sendfile-0.2.28-2jBEu40P91F3SXyDycEM4A
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 11a03b2316d088d25c8dfc24e871c4b7
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/simple-sendfile-0.2.28
hs-libraries: HSsimple-sendfile-0.2.28-2jBEu40P91F3SXyDycEM4A
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.28-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.28
id: simple-sendfile-0.2.28-KERb7ia4J6u2jyxwMYMLAg
key: simple-sendfile-0.2.28-KERb7ia4J6u2jyxwMYMLAg
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 78e8c051e8d56f821705fa1c9817404e
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/simple-sendfile-0.2.28
hs-libraries: HSsimple-sendfile-0.2.28-KERb7ia4J6u2jyxwMYMLAg
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.8.0.0-xbHtkcSHJTFxVBp7aTame unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
